@@ -153,7 +153,7 @@ Summary: MySQL - server with Berkeley BD, RAID and UDF support
 Group: Applications/Databases
 Provides: mysql-Max
 Obsoletes: mysql-Max
-Requires: MySQL >= 4.0
+Requires: MySQL-server >= 4.0
 
 %description Max 
 Optional MySQL server binary that supports additional features like
@@ -282,7 +282,18 @@ mv sql/mysqld sql/mysqld-max
 nm --numeric-sort sql/mysqld-max > sql/mysqld-max.sym
 
 # Install embedded server library in the build root
-install -m 644 libmysqld/libmysqld.a $RBR%{_libdir}/mysql
+install -m 644 libmysqld/libmysqld.a $RBR%{_libdir}/mysql/
+
+# Include libgcc.a in the devel subpackage (BUG 4921)
+if [ "$CC" = gcc ]
+then
+  libgcc=`$CC --print-libgcc-file`
+  if [ -f $libgcc ]
+  then
+    %define have_libgcc 1
+    install -m 644 $libgcc $RBR%{_libdir}/mysql/libmygcc.a
+  fi
+fi
 
 # Save libraries
 (cd libmysql/.libs; tar cf $RBR/shared-libs.tar *.so*)
@@ -395,7 +406,7 @@ useradd -M -r -d $mysql_datadir -s /bin/bash -c "MySQL server" mysql 2> /dev/nul
 chown -R mysql $mysql_datadir
 
 # Initiate databases
-mysql_install_db -IN-RPM
+mysql_install_db -IN-RPM --user=mysql
 
 # Change permissions again to fix any new files.
 chown -R mysql $mysql_datadir
@@ -446,7 +457,7 @@ fi
 %files server
 %defattr(-,root,root,0755)
 
-%doc COPYING README
+%doc COPYING README 
 %doc Docs/manual.{html,ps,texi,txt}
 %doc Docs/manual_toc.html
 %doc support-files/my-*.cnf
@@ -531,6 +542,7 @@ fi
 
 %files devel
 %defattr(-, root, root, 0755)
+%doc EXCEPTIONS-CLIENT
 %attr(755, root, root) %{_bindir}/comp_err
 %attr(755, root, root) %{_bindir}/mysql_config
 %dir %attr(755, root, root) %{_includedir}/mysql
@@ -539,6 +551,9 @@ fi
 %{_libdir}/mysql/libdbug.a
 %{_libdir}/mysql/libheap.a
 %{_libdir}/mysql/libmerge.a
+%if %{have_libgcc}
+%{_libdir}/mysql/libmygcc.a
+%endif
 %{_libdir}/mysql/libmyisam.a
 %{_libdir}/mysql/libmyisammrg.a
 %{_libdir}/mysql/libmysqlclient.a
@@ -573,8 +588,22 @@ fi
 %attr(644, root, root) %{_libdir}/mysql/libmysqld.a
 
 # The spec file changelog only includes changes made to the spec file
-# itself
+# itself - note that they must be ordered by date (important when
+# merging BK trees)
 %changelog 
+* Thu Aug 26 2004 Lenz Grimmer <lenz@mysql.com>
+
+- MySQL-Max now requires MySQL-server instead of MySQL (BUG 3860)
+
+* Tue Aug 10 2004 Lenz Grimmer <lenz@mysql.com>
+
+- Added libmygcc.a to the devel subpackage (required to link applications
+  against the the embedded server libmysqld.a) (BUG 4921)
+
+* Mon Aug 09 2004 Lenz Grimmer <lenz@mysql.com>
+
+- Added EXCEPTIONS-CLIENT to the "devel" package
+
 * Mon Apr 05 2004 Lenz Grimmer <lenz@mysql.com>
 
 - added ncurses-devel to the build prerequisites (BUG 3377)
